@@ -5,6 +5,7 @@ import (
 	"errors"
 	"fmt"
 	"strings"
+	"sync/atomic"
 	"time"
 
 	"github.com/AlecAivazis/survey/v2"
@@ -23,6 +24,7 @@ type deleteOptions struct {
 	keepDays      uint16
 	orgName       string
 	userName      string
+	repoOwner     string
 
 	isInteractive bool
 	now           func() time.Time
@@ -60,10 +62,12 @@ func newDeleteCmd(app *App) *cobra.Command {
 			// After the admin subcommand is added (see https://github.com/cli/cli/pull/6944#issuecomment-1419553639) we can revisit this.
 			opts.codespaceName = selector.codespaceName
 			opts.repoFilter = selector.repoName
+			opts.repoOwner = selector.repoOwner
 
 			if opts.deleteAll && opts.repoFilter != "" {
 				return cmdutil.FlagErrorf("both `--all` and `--repo` is not supported")
 			}
+
 			if opts.orgName != "" && opts.codespaceName != "" && opts.userName == "" {
 				return cmdutil.FlagErrorf("using `--org` with `--codespace` requires `--user`")
 			}
@@ -89,17 +93,21 @@ func (a *App) Delete(ctx context.Context, opts deleteOptions) (err error) {
 	var codespaces []*api.Codespace
 	nameFilter := opts.codespaceName
 	if nameFilter == "" {
-		a.StartProgressIndicatorWithLabel("Fetching codespaces")
-		userName := opts.userName
-		if userName == "" && opts.orgName != "" {
-			currentUser, err := a.apiClient.GetUser(ctx)
-			if err != nil {
-				return err
+		err = a.RunWithProgress("Fetching codespaces", func() (fetchErr error) {
+			userName := opts.userName
+			if userName == "" && opts.orgName != "" {
+				currentUser, fetchErr := a.apiClient.GetUser(ctx)
+				if fetchErr != nil {
+					return fetchErr
+				}
+				userName = currentUser.Login
 			}
-			userName = currentUser.Login
-		}
-		codespaces, err = a.apiClient.ListCodespaces(ctx, api.ListCodespacesOptions{OrgName: opts.orgName, UserName: userName})
-		a.StopProgressIndicator()
+			codespaces, fetchErr = a.apiClient.ListCodespaces(ctx, api.ListCodespacesOptions{OrgName: opts.orgName, UserName: userName})
+			if opts.repoOwner != "" {
+				codespaces = filterCodespacesByRepoOwner(codespaces, opts.repoOwner)
+			}
+			return
+		})
 		if err != nil {
 			return fmt.Errorf("error getting codespaces: %w", err)
 		}
@@ -113,17 +121,15 @@ func (a *App) Delete(ctx context.Context, opts deleteOptions) (err error) {
 			nameFilter = c.Name
 		}
 	} else {
-		a.StartProgressIndicatorWithLabel("Fetching codespace")
-
 		var codespace *api.Codespace
-		var err error
-
-		if opts.orgName == "" || opts.userName == "" {
-			codespace, err = a.apiClient.GetCodespace(ctx, nameFilter, false)
-		} else {
-			codespace, err = a.apiClient.GetOrgMemberCodespace(ctx, opts.orgName, opts.userName, opts.codespaceName)
-		}
-		a.StopProgressIndicator()
+		err := a.RunWithProgress("Fetching codespace", func() (fetchErr error) {
+			if opts.orgName == "" || opts.userName == "" {
+				codespace, fetchErr = a.apiClient.GetCodespace(ctx, nameFilter, false)
+			} else {
+				codespace, fetchErr = a.apiClient.GetOrgMemberCodespace(ctx, opts.orgName, opts.userName, opts.codespaceName)
+			}
+			return
+		})
 		if err != nil {
 			return fmt.Errorf("error fetching codespace information: %w", err)
 		}
@@ -140,6 +146,7 @@ func (a *App) Delete(ctx context.Context, opts deleteOptions) (err error) {
 		if opts.repoFilter != "" && !strings.EqualFold(c.Repository.FullName, opts.repoFilter) {
 			continue
 		}
+
 		if opts.keepDays > 0 {
 			t, err := time.Parse(time.RFC3339, c.LastUsedAt)
 			if err != nil {
@@ -169,25 +176,34 @@ func (a *App) Delete(ctx context.Context, opts deleteOptions) (err error) {
 	if len(codespacesToDelete) > 1 {
 		progressLabel = "Deleting codespaces"
 	}
-	a.StartProgressIndicatorWithLabel(progressLabel)
-	defer a.StopProgressIndicator()
 
-	var g errgroup.Group
-	for _, c := range codespacesToDelete {
-		codespaceName := c.Name
-		g.Go(func() error {
-			if err := a.apiClient.DeleteCodespace(ctx, codespaceName, opts.orgName, opts.userName); err != nil {
-				a.errLogger.Printf("error deleting codespace %q: %v\n", codespaceName, err)
-				return err
-			}
-			return nil
-		})
+	var deletedCodespaces uint32
+	err = a.RunWithProgress(progressLabel, func() error {
+		var g errgroup.Group
+		for _, c := range codespacesToDelete {
+			codespaceName := c.Name
+			g.Go(func() error {
+				if err := a.apiClient.DeleteCodespace(ctx, codespaceName, opts.orgName, opts.userName); err != nil {
+					a.errLogger.Printf("error deleting codespace %q: %v\n", codespaceName, err)
+					return err
+				}
+				atomic.AddUint32(&deletedCodespaces, 1)
+				return nil
+			})
+		}
+
+		if err := g.Wait(); err != nil {
+			return fmt.Errorf("%d codespace(s) failed to delete", len(codespacesToDelete)-int(deletedCodespaces))
+		}
+		return nil
+	})
+
+	if a.io.IsStdoutTTY() && deletedCodespaces > 0 {
+		successMsg := fmt.Sprintf("%d codespace(s) deleted successfully\n", deletedCodespaces)
+		fmt.Fprint(a.io.ErrOut, successMsg)
 	}
 
-	if err := g.Wait(); err != nil {
-		return errors.New("some codespaces failed to delete")
-	}
-	return nil
+	return err
 }
 
 func confirmDeletion(p prompter, apiCodespace *api.Codespace, isInteractive bool) (bool, error) {
@@ -204,6 +220,7 @@ func confirmDeletion(p prompter, apiCodespace *api.Codespace, isInteractive bool
 type surveyPrompter struct{}
 
 func (p *surveyPrompter) Confirm(message string) (bool, error) {
+	prompter := &Prompter{}
 	var confirmed struct {
 		Confirmed bool
 	}
@@ -215,7 +232,7 @@ func (p *surveyPrompter) Confirm(message string) (bool, error) {
 			},
 		},
 	}
-	if err := ask(q, &confirmed); err != nil {
+	if err := prompter.Ask(q, &confirmed); err != nil {
 		return false, fmt.Errorf("failed to prompt: %w", err)
 	}
 
